@@ -175,7 +175,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         self._get_info_dataset_by_slug(slug)
         return self
 
-    def query(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50):
+    def query(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0):
 
         if(fields==[]):
             print("SELECT FIELDS")
@@ -215,7 +215,8 @@ class Agent(Insight, Channel, Catalog, Dataset):
             "fields": fields,
             "sortedBy": sorted_by,
             "filters": filters,
-            "limit": limit
+            "limit": limit,
+            "offset": offset
         }
 
         print(body)
@@ -255,7 +256,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
                 columns.append(col["name"])
             else:
                 columns.append(col["code"])
-        df = pd.DataFrame(columns=codes, data=response["data"])
+        df = pd.DataFrame(columns=codes, data=r["data"])
         df.columns = columns
         return df
 
@@ -626,7 +627,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         else:
             raise Exception('Please give either a dataset id or a dataset slug')
 
-    def create_datacard(self, channel_name: str, title: str, search: str = "", slug: str = None, replace: bool = False):
+    def create_datacard(self, channel_name: str, title: str, search: str = "", slug: str = None, skin_code:str = None, replace: bool = False):
 
         if (replace == True and slug != None):
             try:
@@ -639,7 +640,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
             return
 
         channel = self.get_channel(channel_name)
-        if channel != None:
+        if channel is not None:
             channel_id = channel["id"]
         else:
             channel_id = self.create_channel(channel_name)
@@ -651,6 +652,9 @@ class Agent(Insight, Channel, Catalog, Dataset):
             "slug": slug
         }
 
+        if skin_code is not None:
+            body["ui"]= {"skin" : skin_code}
+
         if self._env == 'dev':
             smart_insight_url = url_list['BASE_URL_INSIGHT_DEV']
         if self._env == 'qa':
@@ -763,6 +767,38 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         return slug
 
+    def list_datasets(self):
+
+        if self._env == 'dev':
+            self._base_url_dataset = url_list['BASE_URL_DATASET_DEV']
+        elif self._env == 'qa':
+            self._base_url_dataset = url_list['BASE_URL_DATASET_QA']
+        elif self._env == 'prod':
+            self._base_url_dataset = url_list['BASE_URL_DATASET_PROD']
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        dataset_url = self._base_url_dataset + '/datasets?agentId=' + self._agentId
+        response = s.get(url=dataset_url, headers=self._headers)
+        response.raise_for_status()
+        r = response.json()
+        r_df = pd.DataFrame(r)
+
+        try:
+            if r_df.empty:
+                raise Exception('No datasets in the agent {}'.format(self._agentId))
+            else:
+                datasets_df = r_df.loc[:, ['id', 'domain', 'type', 'code', 'name', 'slug', 'description', 'createdBy', 'isActive',
+                                     'accessType', 'icon', 'version', 'syncCount', 'visible', 'public', 'createdAt']]
+        except Exception as e:
+            datasets_df = r_df
+            logging.info(e)
+
+        return datasets_df
+
 
 class Askdata(SignUp):
     '''
@@ -840,7 +876,12 @@ class Askdata(SignUp):
     def get_token(self, username, password):
         return self._token
 
-    def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=False, dataset_name="", locale="en"):
+    def normalize_columns(self, df:pd.DataFrame):
+
+        from askdata import integration as ig
+        return ig.normalize_columns(df)
+
+    def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=True, dataset_name="", locale="en"):
 
 
         for col in df.columns:
