@@ -49,3 +49,26 @@ Usage example: read_alphavantage_stock(api_key, symbols)
 def read_alphavantage_stock(symbols, api_key):
     from askdata.integrations import alphavantage
     return alphavantage.get_daily_adjusted_df(symbols, api_key)
+
+def normalize_columns(df:pd.DataFrame):
+
+    problematicChars = [",", ";", ":", "{", "}", "(", ")", "=", ">", "<", "."]
+    new_cols={}
+    for column in df.columns:
+
+        columnName = column.lower()
+
+        for p_char in problematicChars:
+            columnName = columnName.replace(p_char, "")
+
+        columnName = columnName.replace(" ", "_")
+        columnName = columnName.replace("-", "_")
+        columnName = columnName.strip()
+
+
+        for p_char in problematicChars:
+            columnName = columnName.replace(p_char, "")
+
+        new_cols[column] = columnName
+
+    return df.rename(columns= new_cols)
